
**Copyright**
    |copy| 2008-2019 Jonathan F. Donges and pyunicorn authors.

**License**
    BSD (3-clause)

**URL**
    http://www.pik-potsdam.de/members/donges/software

**Mail**
    Jonathan Donges, Potsdam Institute for Climate Impact Research,
    P.O. Box 60 12 03, D-14412 Potsdam, Germany

**Authors**
    Written as part of a diploma/PhD thesis in physics by `Jonathan F. Donges
    <donges@pik-potsdam.de>`_ at Humboldt University Berlin and the Potsdam
    Institute for Climate Impact Research (PIK) and completed at the University
    of Potsdam, Germany. Substantially extended by `Jobst Heitzig
    <heitzig@pik-potsdam.de>`_.

**Contributors**
    - Jakob Runge (extended ``core`` and ``climate``)
    - Alexander Radebach
    - Hanna Schultz
    - Marc Wiedermann (extended ``core`` and ``climate``)
    - `Alraune Zech <alrauni@web.de>`_
      (extended ``timeseries`` during an internship at PIK)
    - `Jan Feldhoff <feldhoff@pik-potsdam.de>`_ (extended ``timeseries``)
    - Aljoscha Rheinwalt
    - Hannes Kutza
    - `Boyan Beronov <beronov@pik-potsdam.de>`_ (restructured,
      consolidated and updated codebase during an internship at PIK)
    - `Paul Schultz <pschultz@pik-potsdam.de>`_, `Stefan Schinkel
      <mail@dreeg.org>`_ (supplied ``resistive_network`` and corresponding
      tests)
    - `Wolfram Barfuss <barfuss@pik-potsdam.de>`_ (package extensions and maintenance)
    - Nils Harmening (cythonized ``weave.inline`` functions, extended testing
      framework, migrated from Python 2.7 to 3.6)
    - Jonathan Krönke (extending test framework, package extensions and maintenance)

**Related publications**
    See `Publications <docs/source/publications.rst>`_.

**Dependencies**
    - Python 3.7
    - `Numpy <http://www.numpy.org/>`_ 1.14+
    - `Scipy <http://www.scipy.org/>`_ 1.0+
    - `Cython <http://cython.org/>`_ 0.27+
    - `Matplotlib <http://matplotlib.org/>`_ 2.0+
    - `igraph, python-igraph <http://igraph.org/>`_ 0.7+

**Included**
    - `progressbar <http://pypi.python.org/pypi/progressbar/>`_ 2.3

**To Do**
  - A lot - See current product backlog.

**Known Bugs**:
  - See GitHub issues list.
